<?php 
/**
 * Admin callbacks.
 *
 * @since      1.1.0
 * @package    RevivePress
 * @subpackage RevivePress\Api\Callbacks
 * @author     Sayan Datta <iamsayan@protonmail.com>
 */

namespace RevivePress\Api\Callbacks;

use RevivePress\Base\BaseController;

defined( 'ABSPATH' ) || exit;

/**
 * Admin callbacks class.
 */
class AdminCallbacks extends BaseController
{
	/**
	 * Call dashboard template.
	 */
	public function adminDashboard() {
		$options = get_option( 'wpar_plugin_settings' );
		$last = get_option( 'wpar_last_global_cron_run' );
        $format = get_option( 'date_format' ) . ' @ ' . get_option( 'time_format' );
		$class_name = revivepress_fs()->can_use_premium_code__premium_only() ? ' premium' : '';

		return require_once( $this->plugin_path . 'templates/admin.php' );
	}

	public function subMenu( $items, $class ) {
		$allowed_html = array( 'i' => array( 'class' => array() ) );
		$sub_items = array();
		foreach ( $items as $item => $title ) {
			$sub_items[] = '<a href="#" class="sub-link sub-link-' . esc_attr( $item ) . '" data-type="' . esc_attr( $item ) . '">' . wp_kses( $title, $allowed_html ) . '</a>';
		}

		if ( ! empty( $sub_items ) ) {
			echo '<div class="postbox sub-links wpar-' . esc_attr( $class ) . ' d-none">';
			echo join( '<span>&#124;</span>', $sub_items ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			echo '</div>';
		}
	}

	public function sectionHeader( $title, $description ) { ?>
		<div class="wpar-metabox-holder">
			<div class="wpar-metabox-td">
				<h3 class="wpar-metabox-title"><?php echo esc_html( $title ); ?></h3>
				<p class="wpar-metabox-description"><?php echo wp_kses_post( $description ); ?></p>
			</div>
		</div>
		<?php
	}

	public function doSettingsSection( $attr ) {
		$social_accounts = false;
		if ( revivepress_fs()->can_use_premium_code__premium_only() ) {
			if ( isset( $attr['type'] ) && ! empty( $attr['type'] ) ) {
				$social_type = $attr['type'];
			}

			if ( isset( $social_type ) ) {
				$social_accounts = apply_filters( 'wpar/display_' . $social_type . '_accounts', false );
			}
		} ?>
		<div id="<?php echo esc_attr( $attr['id'] ); ?>" class="postbox <?php echo esc_attr( $attr['class'] ); ?>">
			<?php $this->sectionHeader( $attr['title'], $attr['description'] ); ?>
			<div class="inside">
				<?php do_settings_sections( $attr['name'] );
				if ( revivepress_fs()->can_use_premium_code__premium_only() ) {
					if ( $social_accounts !== false ) { ?>
						<div id="wpar-<?php echo esc_attr( $social_type ); ?>-accounts-list" class="wpar-has-table">
							<?php 
								echo $social_accounts; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
							?>
						</div>
					<?php }
					if ( isset( $social_type ) ) {
						do_action( 'wpar/social_auth_fields', $social_type );
					}
				} ?>
			</div>
			<p class="wpar-control-area">
				<?php submit_button( __( 'Save Settings', 'wp-auto-republish' ), 'primary wpar-save', '', false ); ?>
				<?php if ( revivepress_fs()->can_use_premium_code__premium_only() ) { ?>
					<?php if ( isset( $social_type ) ) { ?>
						<span id="wpar-<?php echo esc_attr( $social_type ); ?>-control" class="wpar-social-control">
							<input type="button" class="button wpar-add-social-account" data-account-type="<?php echo esc_attr( $social_type ); ?>" data-content="wpar-<?php echo esc_attr( $social_type ); ?>-form" data-processing="<?php esc_attr_e( 'Processing...', 'wp-auto-republish' ); ?>" value="<?php esc_attr_e( 'Add New / Re-Authorize Account', 'wp-auto-republish' ); ?>">
							<span class="nonce-success" style="display: none;color: #068611;padding-left: 15px;"><?php esc_html_e( 'Success!', 'wp-auto-republish' ); ?></span>
							<span class="nonce-error" style="display: none;color: #ff0000;padding-left: 15px;"><?php esc_html_e( 'Error: Invalid Nonce!', 'wp-auto-republish' ); ?></span>
							<span class="spinner"></span></span>
							<?php if ( $social_accounts !== false ) { ?>
								<input type="button" class="button wpar-db-remove wpar-<?php echo esc_attr( $social_type ); ?>-btn-remove" data-account-type="<?php echo esc_attr( $social_type ); ?>" data-notice="<?php esc_attr_e( 'It will remove all authorized active accounts and you have to reauthorize all your accounts again. Do you want to continue?', 'wp-auto-republish' ); ?>" data-success="<?php esc_attr_e( 'Success! All Accounts removed successfully!', 'wp-auto-republish' ); ?>" value="<?php esc_attr_e( 'Remove All Accounts', 'wp-auto-republish' ); ?>">
							<?php } ?>
						</span>
					<?php } ?>
				<?php } ?>
			</p>
		</div>
		<?php
	}

	public function systemStatus() {
		$info = array();

		$info['memory_limit'] = array(
			'label'       => __( 'PHP memory limit' ), // phpcs:ignore WordPress.WP.I18n.MissingArgDomain
			'value'       => ini_get( 'memory_limit' ),
			'minimum'     => '256M',
			'recommended' => '512M',
		);

		$info['max_execution_time'] = array(
			'label'       => __( 'PHP time limit' ), // phpcs:ignore WordPress.WP.I18n.MissingArgDomain
			'value'       => ini_get( 'max_execution_time' ),
			'minimum'     => 300,
			'recommended' => 600,
		);
		
		$info['max_input_time'] = array(
			'label'       => __( 'Max input time' ), // phpcs:ignore WordPress.WP.I18n.MissingArgDomain
			'value'       => ini_get( 'max_input_time' ),
			'minimum'     => 120,
			'recommended' => 300,
		); ?>

		<div class="table-php-requirements-container">
			<table class="table-php-requirements" style="text-align: left;">
				<thead>
					<tr>
						<th><?php esc_html_e( 'Name', 'wp-auto-republish' ); ?></th>
						<th><?php esc_html_e( 'Directive', 'wp-auto-republish' ); ?></th>
						<th><?php esc_html_e( 'Least Suggested', 'wp-auto-republish' ); ?></th>
						<th><?php esc_html_e( 'Recommended', 'wp-auto-republish' ); ?></th>
						<th><?php esc_html_e( 'Current Value', 'wp-auto-republish' ); ?></th>
					</tr>
				</thead>
				<tbody>
					<?php foreach ( $info as $key => $data ) { ?>
						<tr>
							<td><?php echo esc_html( $data['label'] ); ?></td>
							<td><?php echo esc_html( $key ); ?></td>
							<td class="bold"><?php echo esc_html( $data['minimum'] ); ?></td>
							<td class="bold"><?php echo esc_html( $data['recommended'] ); ?></td>
							<td class="bold"><?php echo esc_html( $data['value'] ); ?></td>
						</tr>
					<?php } ?>
				</tbody>
			</table>
			<p>
				<?php printf( 
					/* translators: 1: <a> tag start, 2: </a> tag end. */
					esc_html__( 'To change PHP directives you need to modify php.ini file, more information about this you can %1$ssearch here%2$s or contact your hosting provider. See Site Health for more.', 'wp-auto-republish' ), '<a href="http://goo.gl/I9f74U" target="_blank" rel="noopener">', '</a>'
				); ?>
				<?php if ( defined( 'DISABLE_WP_CRON' ) && true === DISABLE_WP_CRON ) {
					esc_html_e( 'WordPress Cron is currently disabled. Please enable it if you are facing asny issue.', 'wp-auto-republish' );
				} ?>
			</p>
		</div>
		<?php
	}
}