<?php
/**
 * Rule Capabilities
 *
 * @since      1.3.4
 * @package    RevivePress
 * @subpackage RevivePress\Core\Premium
 * @author     Sayan Datta <iamsayan@protonmail.com>
 */

namespace RevivePress\Core\Premium;

use RevivePress\Helpers\Hooker;
use RevivePress\Helpers\Premium\Extras;

defined( 'ABSPATH' ) || exit;

/**
 * Single post cache class.
 */
class Capabilities
{
	use Extras;
    use Hooker;

	/**
	 * Caps that need to be set
	 *
	 * @var array
	 */
	private static $post_types = array(
		'republish_rule',
		'republish_log',
	);

	/**
	 * Register functions.
	 */
	public function register() {
		$this->action( 'wpar/plugin_activate', 'add_caps' );
		$this->action( 'wpar/plugin_deactivate', 'remove_caps' );
	}

	/**
	 * Add Capabilities to admins
	 * 
	 * @since 1.3.2
	 */
	public function add_caps() {
		// gets the administrator role
		$role_object = get_role( 'administrator' );
		if ( is_null( $role_object ) || ! $role_object instanceof \WP_Role ) {
			return;
		}

		foreach ( self::$post_types as $post_type ) {
			$caps = $this->get_capabilities( $post_type );
			foreach ( $caps as $cap ) {
				$role_object->add_cap( $cap );
			}
		}
	}

	/**
	 * Remove Capabilities from admins
	 * 
	 * @since 1.3.2
	 */
	public function remove_caps() {
		// gets the administrator role
		$role_object = get_role( 'administrator' );
		if ( is_null( $role_object ) || ! $role_object instanceof \WP_Role ) {
			return;
		}

		foreach ( self::$post_types as $post_type ) {
			$caps = $this->get_capabilities( $post_type );
			foreach ( $caps as $cap ) {
				$role_object->remove_cap( $cap );
			}
		}
	}
}