<?php
/**
 * Filter post statuses.
 *
 * @since      1.2.0
 * @package    RevivePress
 * @subpackage RevivePress\Core\Premium
 * @author     Sayan Datta <iamsayan@protonmail.com>
 */

namespace RevivePress\Core\Premium;

use RevivePress\Helpers\Hooker;
use RevivePress\Helpers\HelperFunctions;

defined( 'ABSPATH' ) || exit;

/**
 * Filter post statuses class.
 */
class PostStatusFilters
{
	use HelperFunctions;
    use Hooker;

	/**
	 * Register functions.
	 */
	public function register() {
		$this->filter( 'pre_get_posts', 'filter_posts' );

		$post_types = $this->do_filter( 'filter_post_types', $this->get_post_types( true ) );
		foreach ( $post_types as $post_type ) {
			$this->filter( "views_edit-{$post_type}", 'content_filter' );
		}
	}

	/**
	 * Add view to filter list for Pending republish posts.
	 *
	 * @param array $views An array of available list table views.
	 */
	public function content_filter( $views ) {
		global $typenow;

		$enabled = $this->do_filter( 'show_filter_link', true, $typenow );
		$current = empty( $_GET['republish_pending'] ) ? '' : ' class="current" aria-current="page"';
		$get_posts = get_posts(
			array(
				'post_type'      => $typenow,
				'fields'         => 'ids',
				'posts_per_page' => -1,
				'post_status'    => 'any',
				'meta_query'     => array(
					'relation' => 'AND',
					array(
		    	    	'key'     => 'wpar_filter_republish_status',
    			        'compare' => 'EXISTS',
					),
		    	    array(
		    	    	'key'     => '_wpar_filter_republish_datetime',
		    	    	'compare' => 'EXISTS',
		    	    ),
				),
			)
		);

		if ( count( $get_posts ) > 0 && $enabled ) {
	    	$views['republish_pending'] = sprintf(
	    		'<a href="%1$s"%2$s>%3$s <span class="count">(%4$s)</span></a>',
	    		add_query_arg(
	    			array(
	    				'post_type'         => $typenow,
	    				'republish_pending' => 1,
	    			),
	    		    admin_url( 'edit.php' ) 
	    	    ),
	    		$current,
	    		esc_html__( 'Republish Pending', 'wp-auto-republish' ),
	    		number_format_i18n( count( $get_posts ) )
	    	);
	    }
    
		return $views;
	}

	/**
	 * Filter posts in admin by Post meta value.
	 *
	 * @param \WP_Query $query The wp_query instance.
	 */
	public function filter_posts( $query ) {
		$order = $this->get_data( 'post_sorting_order', 'default' );
		if ( 'default' !== $order && ! is_admin() && $query->is_main_query() ) {
			if ( $query->is_home() || $query->is_category() || $query->is_tag() ) {
				$query->set( 'order', $order );
				$query->set( 'orderby', 'meta_value' );
				$query->set( 'meta_key', '_wpar_original_pub_date' );
			}
		}

		if ( ! empty( $_GET['republish_pending'] ) && is_admin() ) {
		    $meta_query = array(
				'relation' => 'AND',
		    	array(
					'key'     => 'wpar_filter_republish_status',
					'compare' => 'EXISTS',
				),
		    	array(
		    		'key'     => '_wpar_filter_republish_datetime',
		    		'compare' => 'EXISTS',
		    	),
		    );

			$query->set( 'order', 'ASC' );
			$query->set( 'orderby', 'meta_value' );
			$query->set( 'meta_key', '_wpar_filter_republish_datetime' );
			$query->set( 'meta_query', $meta_query );
		}
	}
}