<?php
/**
 * Meta Box.
 *
 * @since      1.2.5
 * @package    RevivePress
 * @subpackage RevivePress\Core\Premium\Rules
 * @author     Sayan Datta <iamsayan@protonmail.com>
 */

namespace RevivePress\Core\Premium\Rules;

use RevivePress\Helpers\Hooker;
use RevivePress\Helpers\Premium\GetMetaData;

defined( 'ABSPATH' ) || exit;

/**
 * Post Metabox class.
 */
class RuleMetaBox
{
	use Hooker;
    use GetMetaData;

	/**
	 * Register functions.
	 */
	public function register() {
		$this->action( 'add_meta_boxes', 'generate_metabox', 10, 2 );
		$this->action( 'save_post_republish_rule', 'save_metadata' );
	}

	/**
	 * Register metaboxes.
	 * 
	 * @param post $post The post object
	 */
	public function generate_metabox( $post_type, $post ) {
		// If user can't publish posts, then get out
		if ( ! current_user_can( 'publish_posts' ) ) {
			return;
		}

		if ( $this->do_filter( 'show_republish_meta_boxes', true, $post ) ) {
		    add_meta_box( 'wpar_meta_box', __( 'Configure Rule', 'wp-auto-republish' ), array( $this, 'single_callback' ), 'republish_rule', 'normal', 'high' );
	    }
	}
	
	/**
	 * Build republish date meta box.
	 *
	 * @param object $post The post object
	 */
	public function single_callback( $post ) {
		$timestamp = $this->current_timestamp();
		$start_time = $this->get_data( 'wpar_start_time', '05:00:00' );

		$repost_option = $this->get_meta( $post->ID, '_wpar_repost_option' );
		$repost_after_number = $this->get_meta( $post->ID, '_wpar_repost_after_number' );
		$repost_after_time = $this->get_meta( $post->ID, '_wpar_repost_after_time' );
		$repost_on_date = $this->get_meta( $post->ID, '_wpar_repost_on_date', date( 'm/d/Y', $timestamp ) );
		
		$repost_repeats = $this->get_meta( $post->ID, '_wpar_repost_repeats' );
		$repost_every = $this->get_meta( $post->ID, '_wpar_repost_every' );
		$repost_monthly_on = $this->get_meta( $post->ID, '_wpar_repost_monthly_on', array(), true );
		$repost_by = $this->get_meta( $post->ID, '_wpar_repost_by' );
		$repost_start = $this->get_meta( $post->ID, '_wpar_repost_start', date( 'm/d/Y', $timestamp ) );
		
		$repost_end = $this->get_meta( $post->ID, '_wpar_repost_end' );
		$repost_end_after = $this->get_meta( $post->ID, '_wpar_repost_end_after' );
		$repost_end_on = $this->get_meta( $post->ID, '_wpar_repost_end_on', date( 'm/d/Y', strtotime( '+2 days', $timestamp ) ) );
		$repost_status = $this->get_meta( $post->ID, '_wpar_repost_last_republish_status' );
	
		$repost_schedule = $this->get_meta( $post->ID, '_wpar_repost_schedule' );
		$repost_at_time = $this->get_meta( $post->ID, '_wpar_repost_at_specific_time', $start_time );
		$repost_enable = $this->get_meta( $post->ID, '_wpar_repost_done' );
		$repost_datetime = $this->get_meta( $post->ID, '_wpar_repost_schedule_datetime' );
		$repost_include_date = $this->get_meta( $post->ID, '_wpar_include_starts_on' );
		$custom_date_time = $this->get_meta( $post->ID, '_wpar_custom_date_time' );
		
		$repost_start_time = $this->get_meta( $post->ID, '_wpar_repost_start_time' );
		$repost_end_time = $this->get_meta( $post->ID, '_wpar_repost_end_time' );

		$post_types_meta = $this->get_meta( $post->ID, '_wpar_repost_post_types', array( 'post' ), true );
		$post_statuses_meta = $this->get_meta( $post->ID, '_wpar_repost_post_statuses', array( 'publish' ), true );
		$taxonomies_filter_meta = $this->get_meta( $post->ID, '_wpar_repost_taxonomies_filter', 'include' ); 
		$taxonomies_meta = $this->get_meta( $post->ID, '_wpar_repost_taxonomies', array(), true ); 
		$authors_filter_meta = $this->get_meta( $post->ID, '_wpar_repost_authors_filter', 'include' ); 
		$authors_meta = $this->get_meta( $post->ID, '_wpar_repost_authors', array(), true ); 
		$post_order = $this->get_meta( $post->ID, '_wpar_repost_post_order', 'old_first' );
		$post_orderby = $this->get_meta( $post->ID, '_wpar_repost_post_orderby', 'date' );
		$randomness = $this->get_meta( $post->ID, '_wpar_repost_post_randomness', 60 );
		$eligibility_age = $this->get_meta( $post->ID, '_wpar_repost_eligibility_age', '' );
		$eligibility_age_max = $this->get_meta( $post->ID, '_wpar_repost_eligibility_age_max', '' );
		$eligibility_exclude_before = $this->get_meta( $post->ID, '_wpar_repost_eligibility_exclude_before', '' );
		$thumbnail_status = $this->get_meta( $post->ID, '_wpar_repost_check_thumbnail', 'disable' );
		$sticky_ignore = $this->get_meta( $post->ID, '_wpar_repost_sticky_ignore', 'disable' );
		$number_posts = $this->get_meta( $post->ID, '_wpar_repost_number_posts', 1 );
		$republish_action = $this->get_meta( $post->ID, '_wpar_repost_republish_action', 'repost' );

		$hide_checkbox = true;
		$datetime_stamp = strtotime( date( 'H:i:s', strtotime( $repost_datetime ) ) );
		$current_datetime_stamp = strtotime( date( 'H:i:s', strtotime( 'now' ) ) );

		if ( ( strtotime( $repost_datetime ) > strtotime( 'now' ) && $datetime_stamp > $current_datetime_stamp ) || $repost_include_date === 'yes' ) {
			$hide_checkbox = false;
		}
		
		// make sure the form request comes from WordPress
		$this->nonce( 'single' ); ?>

		<div class="wpar-schedule-info wpar-rules">
			<span style="font-weight: 700;"><?php esc_html_e( 'Schedule', 'wp-auto-republish' ); ?>:</span>
			<?php 
			if ( $repost_schedule ) {
				if ( 'disable' !== $repost_option ) {
					printf(
						'<span id="wpar_repost_date">%s</span>',
						$this->get_schedule( $post->ID, 'edit' ) // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					);
				} else {
					printf(
						'<span id="wpar_repost_date">%s</span>',
						esc_html__( 'Disabled', 'wp-auto-republish' )
					);
				}
			} else {
				printf(
					'<span id="wpar_repost_date">%s</span>',
					esc_html__( 'Not set yet', 'wp-auto-republish' )
				);
			} ?>
			<span class="wpar-time-div"<?php if ( empty( $repost_option ) || in_array( $repost_option, array( 'disable', 'custom' ) ) ) { echo ' style="display: none;"'; } ?>><?php esc_html_e( 'at', 'wp-auto-republish' ); ?> <input type="text" name="wpar_repost_at_specific_time" id="wpar_repost_at_specific_time" class="wpar-republish-timepicker" value="<?php echo esc_attr( $repost_at_time ); ?>" readonly="readonly" style="width: 85px;" /></span>
		</div>

		<fieldset class="options wpar-options wpar-cpt">
			<div class="option">
				<label>
					<input type="radio" name="wpar_repost_option" id="wpar_repost_option_1" value="days" <?php checked( 'days', $repost_option ); ?> />
					<?php esc_html_e( 'Republish after', 'wp-auto-republish' ); ?>
					<input type="number" name="wpar_repost_after_number" id="wpar_repost_after_number" value="<?php echo esc_attr( $repost_after_number ); ?>" class="small" min="1" max="365" />
					<select name="wpar_repost_after_time" id="wpar_repost_after_time">
						<option value="days" <?php selected( 'days', $repost_after_time ) ?> ><?php esc_html_e( 'Days', 'wp-auto-republish' ); ?></option>
						<option value="weeks" <?php selected( 'weeks', $repost_after_time ) ?> ><?php esc_html_e( 'Weeks', 'wp-auto-republish' ); ?></option>
						<option value="months" <?php selected( 'months', $repost_after_time ) ?> ><?php esc_html_e( 'Months', 'wp-auto-republish' ); ?></option>
						<option value="years" <?php selected( 'years', $repost_after_time ) ?> ><?php esc_html_e( 'Years', 'wp-auto-republish' ); ?></option>
					</select>
				</label>
			</div>
			<div class="option">
				<label>
					<input type="radio" name="wpar_repost_option" id="wpar_repost_option_2" value="date" <?php checked( 'date', $repost_option ); ?> />
					<?php esc_html_e( 'Republish on', 'wp-auto-republish' ); ?>
					<input type="text" id="wpar-static-date" readonly="readonly" value="<?php echo esc_attr( date( 'd/m/Y', strtotime( $repost_on_date ) ) ); ?>" />
					<input type="hidden" name="wpar_repost_on_date" id="wpar_repost_on_date" value="<?php echo esc_attr( $repost_on_date ); ?>" />
				</label>
			</div>
			<div class="option">
				<label>
					<input type="radio" name="wpar_repost_option" id="wpar_repost_option_3" value="repeat" <?php checked( 'repeat', $repost_option ); ?> />
					<?php esc_html_e('Recurring Schedule', 'wp-auto-republish'); ?>
				</label>
				<div class="sub-option" id="repeat_repost_option"<?php echo ( $repost_option != 'repeat' ) ? ' style="display:none;"' : ''; ?>>
					<div class="row">
						<label>
							<span class="label"><?php esc_html_e( 'Repeats', 'wp-auto-republish' ); ?>:</span>
							<span class="fields">
								<select name="wpar_repost_repeats" id="wpar_repost_repeats">
								    <option value="minutes" <?php selected( 'minutes', $repost_repeats ) ?> ><?php esc_html_e( 'Minutes', 'wp-auto-republish' ); ?></option>
									<option value="hourly" <?php selected( 'hourly', $repost_repeats ) ?> ><?php esc_html_e( 'Hourly', 'wp-auto-republish' ); ?></option>
									<option value="daily" <?php selected( 'daily', $repost_repeats ) ?> ><?php esc_html_e( 'Daily', 'wp-auto-republish' ); ?></option>
									<option value="weekly" <?php selected( 'weekly', $repost_repeats ) ?> ><?php esc_html_e( 'Weekly', 'wp-auto-republish' ); ?></option>
									<option value="monthly" <?php selected( 'monthly', $repost_repeats ) ?> ><?php esc_html_e( 'Monthly', 'wp-auto-republish' ); ?></option>
									<option value="yearly" <?php selected( 'yearly', $repost_repeats ) ?> ><?php esc_html_e( 'Yearly', 'wp-auto-republish' ); ?></option>
								</select>
							</span>
						</label>
					</div>
					<div class="row">
						<label>
							<span class="label"><?php esc_html_e( 'Repeat Every', 'wp-auto-republish' ); ?>:</span>
							<span class="fields">
								<select name="wpar_repost_every" id="wpar_repost_every"><?php
								for ( $i = 1; $i <= 59; $i++ ) {
									printf( '<option value="%1$s" %2$s>%1$s</option>', esc_attr( $i ), selected( $i, $repost_every, false ) );
								}
								?></select>
								<input type="hidden" id="wpar-minute-limit" value="<?php echo esc_attr( $this->do_filter( 'minute_starts_from', 5 ) ); ?>"/>
							</span>
						</label>
					</div>
					<div class="row" id="wpar_repeat_monthly_on_wrap"<?php echo ( $repost_repeats != 'monthly' ) ? ' style="display:none;"' : ''; ?>>
						<span>
							<span class="label"><?php esc_html_e('Repeat On', 'wp-auto-republish'); ?>:</span>
							<span class="fields offset">
								<label class="wpar_checklabel" ><input type="checkbox" name="wpar_repost_monthly_on[]" id="wpar_repost_monthly_on_1" value="january" <?php checked( 1, in_array( 'january', $repost_monthly_on ) ); ?> class="wpar_repost_monthly_on" data-value="0" data-month="<?php esc_attr_e( 'January', 'wp-auto-republish'); ?>" /> <?php esc_html_e( 'January', 'wp-auto-republish'); ?> </label>
								<label class="wpar_checklabel" ><input type="checkbox" name="wpar_repost_monthly_on[]" id="wpar_repost_monthly_on_2" value="february" <?php checked( 1, in_array( 'february', $repost_monthly_on ) ); ?> class="wpar_repost_monthly_on"  data-value="1" data-month="<?php esc_attr_e( 'February', 'wp-auto-republish'); ?>" /> <?php esc_html_e( 'February', 'wp-auto-republish'); ?> </label>
								<label class="wpar_checklabel" ><input type="checkbox" name="wpar_repost_monthly_on[]" id="wpar_repost_monthly_on_3" value="march" <?php checked( 1, in_array( 'march', $repost_monthly_on ) ); ?> class="wpar_repost_monthly_on"  data-value="2" data-month="<?php esc_attr_e( 'March', 'wp-auto-republish'); ?>" /> <?php esc_html_e( 'March', 'wp-auto-republish'); ?> </label>
								<label class="wpar_checklabel" ><input type="checkbox" name="wpar_repost_monthly_on[]" id="wpar_repost_monthly_on_4" value="april" <?php checked( 1, in_array( 'april', $repost_monthly_on ) ); ?> class="wpar_repost_monthly_on" data-value="3" data-month="<?php esc_attr_e( 'April', 'wp-auto-republish'); ?>" /> <?php esc_html_e( 'April', 'wp-auto-republish'); ?> </label>
								<label class="wpar_checklabel" ><input type="checkbox" name="wpar_repost_monthly_on[]" id="wpar_repost_monthly_on_5" value="may" <?php checked( 1, in_array( 'may', $repost_monthly_on ) ); ?> class="wpar_repost_monthly_on" data-value="4" data-month="<?php esc_attr_e( 'May', 'wp-auto-republish'); ?>" /> <?php esc_html_e( 'May', 'wp-auto-republish'); ?> </label>
								<label class="wpar_checklabel" ><input type="checkbox" name="wpar_repost_monthly_on[]" id="wpar_repost_monthly_on_6" value="june" <?php checked( 1, in_array( 'june', $repost_monthly_on ) ); ?> class="wpar_repost_monthly_on" data-value="5" data-month="<?php esc_attr_e( 'June', 'wp-auto-republish'); ?>" /> <?php esc_html_e( 'June', 'wp-auto-republish'); ?> </label>
								<label class="wpar_checklabel" ><input type="checkbox" name="wpar_repost_monthly_on[]" id="wpar_repost_monthly_on_7" value="july" <?php checked( 1, in_array( 'july', $repost_monthly_on ) ); ?> class="wpar_repost_monthly_on" data-value="6" data-month="<?php esc_attr_e( 'July', 'wp-auto-republish'); ?>" /> <?php esc_html_e( 'July', 'wp-auto-republish'); ?> </label>
								<label class="wpar_checklabel" ><input type="checkbox" name="wpar_repost_monthly_on[]" id="wpar_repost_monthly_on_8" value="august" <?php checked( 1, in_array( 'august', $repost_monthly_on ) ); ?> class="wpar_repost_monthly_on" data-value="7" data-month="<?php esc_attr_e( 'August', 'wp-auto-republish'); ?>" /> <?php esc_html_e( 'August', 'wp-auto-republish'); ?> </label>
								<label class="wpar_checklabel" ><input type="checkbox" name="wpar_repost_monthly_on[]" id="wpar_repost_monthly_on_9" value="september" <?php checked( 1, in_array( 'september', $repost_monthly_on ) ); ?> class="wpar_repost_monthly_on" data-value="8" data-month="<?php esc_attr_e( 'September', 'wp-auto-republish'); ?>" /> <?php esc_html_e( 'September', 'wp-auto-republish'); ?> </label>
								<label class="wpar_checklabel" ><input type="checkbox" name="wpar_repost_monthly_on[]" id="wpar_repost_monthly_on_10" value="october" <?php checked( 1, in_array( 'october', $repost_monthly_on ) ); ?> class="wpar_repost_monthly_on" data-value="9" data-month="<?php esc_attr_e( 'October', 'wp-auto-republish'); ?>" /> <?php esc_html_e( 'October', 'wp-auto-republish'); ?> </label>
								<label class="wpar_checklabel" ><input type="checkbox" name="wpar_repost_monthly_on[]" id="wpar_repost_monthly_on_11" value="november" <?php checked( 1, in_array( 'november', $repost_monthly_on ) ); ?> class="wpar_repost_monthly_on" data-value="10" data-month="<?php esc_attr_e( 'November', 'wp-auto-republish'); ?>" /> <?php esc_html_e( 'November', 'wp-auto-republish'); ?> </label>
								<label class="wpar_checklabel" ><input type="checkbox" name="wpar_repost_monthly_on[]" id="wpar_repost_monthly_on_12" value="december" <?php checked( 1, in_array( 'december', $repost_monthly_on ) ); ?> class="wpar_repost_monthly_on" data-value="11" data-month="<?php esc_attr_e( 'December', 'wp-auto-republish'); ?>" /> <?php esc_html_e( 'December', 'wp-auto-republish'); ?> </label>
							</span>
						</span>
					</div>
					<div class="row" id="wpar_repeat_by_wrap"<?php echo ( $repost_repeats != 'monthly' ) ? ' style="display:none;"' : ''; ?>>
						<span>
							<span class="label"><?php esc_html_e( 'Repeat By', 'wp-auto-republish' ); ?>:</span>
							<span class="fields">
								<label><input type="radio" name="wpar_repost_by" id="wpar_repost_by_month" value="month" <?php checked( 'month', $repost_by ); ?> /><?php esc_html_e( 'Day of the month', 'wp-auto-republish' ); ?></label>
								<label><input type="radio" name="wpar_repost_by" id="wpar_repost_by_week" value="week" <?php checked( 'week', $repost_by ); ?> <?php if ( empty( $repost_by ) ) { echo ' checked="checked"'; } ?> /><?php esc_html_e( 'Day of the week', 'wp-auto-republish' ); ?></label>
							</span>
						</span>
					</div>
					<div class="row">
						<label>
							<span class="label"><?php esc_html_e( 'Starts On', 'wp-auto-republish' ); ?>:</span>
							<span class="fields">
								<input type="text" id="wpar-static-repost-start" readonly="readonly" value="<?php echo esc_attr( date( 'd/m/Y', strtotime( $repost_start ) ) ); ?>" />
								<input type="hidden" name="wpar_repost_start" id="wpar_repost_start" value="<?php echo esc_attr( $repost_start ); ?>" /></span>
								<span class="wpar_include_start" <?php echo ( $hide_checkbox ) ? 'display: none;' : ''; ?>>
									<input type="checkbox" id="wpar_include_starts_on" name="wpar_include_starts_on" value="yes" <?php checked( 'yes', $repost_include_date ); ?> />
									<label for="wpar_include_starts_on"><?php esc_html_e( 'Start Republish from this Date', 'wp-auto-republish' ); ?></label>
								</span>
							</span>
						</label>
					</div>
					<div class="row">
						<span class="wpar-ends-on-options">
							<span class="label"><?php esc_html_e( 'Ends On', 'wp-auto-republish' ); ?>:</span>
							<span class="fields">
								<label style="display: block;padding: 3px 0 8px;">
									<input type="radio" name="wpar_repost_end" id="wpar_repost_end" value="never" <?php checked( 'never', $repost_end ); ?><?php if ( empty( $repost_end ) ) { echo ' checked="checked"'; } ?> /> <?php esc_html_e( 'Never', 'wp-auto-republish' ); ?>
								</label>
								<label style="display: block;padding-right: 10px;">
									<input type="radio" name="wpar_repost_end" id="wpar_repost_end_1" value="after" <?php checked( 'after', $repost_end ); ?> /> <?php esc_html_e( 'After', 'wp-auto-republish' ); ?>
									<input type="number" name="wpar_repost_end_after" id="wpar_repost_end_after" value="<?php echo esc_attr( $repost_end_after ); ?>" class="small" min="1" /> <?php esc_html_e( 'occurrences', 'wp-auto-republish' ); ?>
								</label>
								<label style="display: block;padding-right: 10px;">
									<input type="radio" name="wpar_repost_end" id="wpar_repost_end_2" value="on" <?php checked( 'on', $repost_end ); ?> /> <?php esc_html_e( 'Specific Date', 'wp-auto-republish' ); ?>
									<input type="text" id="wpar-repost-end-on" readonly="readonly" value="<?php echo esc_attr( date( 'd/m/Y', strtotime( $repost_end_on ) ) ); ?>" />
									<input type="hidden" name="wpar_repost_end_on" id="wpar_repost_end_on" value="<?php echo esc_attr( $repost_end_on ); ?>" />
								</label>
							</span>
						</span>
					</div>
					<div class="row" id="wpar_last_republish_status" style="margin-top: 5px;<?php echo ( $repost_end == 'never' ) ? 'display: none;' : ''; ?>">
						<label>
							<span class="label"><?php esc_html_e( 'Set Status', 'wp-auto-republish' ); ?>:</span>
							<span class="fields">
								<select name="wpar_repost_last_republish_status" id="wpar_repost_last_republish_status">
									<?php echo '<option value="default"' . selected( 'default', $repost_status ) .  '>' . esc_html__( 'Published', 'wp-auto-republish' ) . '</option>';
									echo '<option value="draft"' . selected( 'draft', $repost_status ) .  '>' . esc_html__( 'Draft', 'wp-auto-republish' ) . '</option>'; ?>
								</select>&nbsp;<?php esc_html_e( 'of this Rule at the time of last rule run', 'wp-auto-republish' ); ?>
							</span>
						</label>
					</div>
					<div class="row" id="wpar_last_republish_time_range" style="margin-top: 5px;<?php echo ( ! in_array( $repost_repeats, array( 'minutes', 'hourly' ) ) ) ? 'display: none;' : ''; ?>">
						<label>
							<span class="label"><?php esc_html_e( 'Time Range', 'wp-auto-republish' ); ?>:</span>
							<span class="fields">
								<label style="padding-right: 10px;"><?php esc_html_e( 'Starts at', 'wp-auto-republish' ); ?>
									<input type="text" name="wpar_repost_start_time" id="wpar-repost-start-time" class="wpar-timepicker" value="<?php echo esc_attr( $repost_start_time ); ?>" placeholder="<?php esc_attr_e( 'No Restriction', 'wp-auto-republish' ); ?>" readonly="readonly" />
								</label>
								<label style="padding-right: 10px;"><?php esc_html_e( 'Ends at', 'wp-auto-republish' ); ?>
									<input type="text" name="wpar_repost_end_time" id="wpar-repost-end-time" class="wpar-timepicker" value="<?php echo esc_attr( $repost_end_time ); ?>" placeholder="<?php esc_attr_e( 'No Restriction', 'wp-auto-republish' ); ?>" readonly="readonly" />
								</label>
							</span>
						</label>
					</div>
				</div>
			</div>
			<div class="option">
				<label>
					<input type="radio" name="wpar_repost_option" id="wpar_repost_option_4" value="custom" <?php checked( 'custom', $repost_option ); ?> />
					<?php esc_html_e( 'Custom Date & Time(s)', 'wp-auto-republish' ); ?>
				</label>
				<div id="wpar_custom_dates" <?php echo ( $repost_option != 'custom' ) ? ' style="display:none;"' : ''; ?>>
					<textarea id="wpar-custom-date-time" name="wpar_custom_date_time" placeholder="<?php esc_attr_e( 'Format: 2022-05-15 09:30:55 (one per line in ascending order)', 'wp-auto-republish' ); ?>" rows="4" cols="50"><?php echo esc_textarea( $custom_date_time ); ?></textarea>
					<div><?php esc_attr_e( 'Format: 2022-05-15 09:30:55 (one per line in ascending order)', 'wp-auto-republish' ); ?></div>
				</div>
			</div>
			<div class="option">
				<label>
					<input type="radio" name="wpar_repost_option" id="wpar_repost_option_5" value="disable" <?php checked( 'disable', $repost_option ); ?><?php if ( empty( $repost_option ) ) { echo ' checked="checked"'; } ?> />
					<?php esc_html_e( 'Disable this Republish Rule', 'wp-auto-republish' ); ?>
				</label>
			</div>
			<input type="hidden" name="wpar_repost_schedule" id="wpar_repost_schedule" value="<?php echo esc_attr( date( 'm/d/Y', strtotime( $repost_schedule ) ) ); ?>" />
			<input type="hidden" name="wpar_repost_done" id="wpar_repost_done" value="<?php echo ( ! empty( $repost_enable ) ) ? esc_attr( $repost_enable ) : 'yes'; ?>" data-last="<?php echo esc_attr( $repost_enable ); ?>" data-republish="<?php echo esc_attr( $repost_datetime ); ?>" />
			<input type="hidden" name="wpar_regenerate_cron" id="wpar_regenerate_cron_event" value="no" />
		</fieldset>

		<fieldset class="options wpar-container">
			<div class="option row">
				<div class="col-12">
					<label for="wpar_repost_post_types">
						<div class="tooltip" class="tooltip">
							<strong><?php esc_html_e( 'Select Post Types that you want to be Republished', 'wp-auto-republish' ); ?>:</strong>
							<span class="tooltiptext"><?php esc_html_e( 'Select the post types of which you want to republish using this Republish Rule.', 'wp-auto-republish' ); ?></span>
						</div>
						<div class="fields">
							<?php $post_types = $this->get_post_types();
							echo '<select id="wpar_repost_post_types" name="wpar_repost_post_types[]" multiple="multiple" required>';
							foreach ( $post_types as $post_type => $label ) {
								echo '<option value="' . esc_attr( $post_type ) . '"' . selected( in_array( $post_type, $post_types_meta ), true, false ) . '>' . esc_html( $label ) . '</option>';
							}
							echo '</select>'; ?>
						</div>
					</label>
				</div>
			</div>
			<div class="option row">
				<div class="col-12">
					<label for="wpar_repost_post_statuses">
						<div class="tooltip" class="tooltip">
							<strong><?php esc_html_e( 'Select Post Status(es) that you want to be Republished', 'wp-auto-republish' ); ?>:</strong>
							<span class="tooltiptext"><?php esc_html_e( 'Select the post status(es) of which you want to republish using this Republish Rule.', 'wp-auto-republish' ); ?></span>
						</div>
						<div class="fields">
							<?php $post_statuses = $this->get_post_statuses();
							echo '<select id="wpar_repost_post_statuses" name="wpar_repost_post_statuses[]" multiple="multiple" required>';
							foreach ( $post_statuses as $slug => $label ) {
								echo '<option value="' . esc_attr( $slug ) . '"' . selected( in_array( $slug, $post_statuses_meta ), true, false ) . '>' . esc_html( $label ) . '</option>';
							}
							echo '</select>'; ?>
						</div>
					</label>
				</div>
			</div>
			<div class="option row">
				<div class="col-3 col-12-sm">
					<label for="wpar_repost_taxonomies_filter">
						<div class="tooltip">
							<strong><?php esc_html_e( 'Select Taxonomies Filter', 'wp-auto-republish' ); ?>:</strong>
							<span class="tooltiptext"><?php esc_html_e( 'Select how you want to include or exclude a post category from republishing. If you choose Exclude Taxonomies, selected taxonomies will be ignored and Include will add them only.', 'wp-auto-republish' ); ?></span>
						</div>
						<?php 
						$items = array(
							'include' => __( 'Include Taxonomies', 'wp-auto-republish' ),
							'exclude' => __( 'Exclude Taxonomies', 'wp-auto-republish' ),
						);
						echo '<select id="wpar_repost_taxonomies_filter" name="wpar_repost_taxonomies_filter">';
						foreach ( $items as $item => $label ) {
							echo '<option value="' . esc_attr( $item ) . '"' . selected( $taxonomies_filter_meta, $item, false ) . '>' . esc_html( $label ) . '</option>';
						}
						echo '</select>';
						?>
					</label>
				</div>
				<div class="col-9 col-12-sm">
					<label for="wpar_repost_taxonomies">
						<div class="tooltip" class="tooltip">
							<strong><?php esc_html_e( 'Select Post / Page / Custom Post Types Taxonomies', 'wp-auto-republish' ); ?>:</strong>
							<span class="tooltiptext"><?php esc_html_e( 'Select taxonomies which you want to filter to republishing using this Republish Rule.', 'wp-auto-republish' ); ?></span>
						</div>
						<div class="fields">
							<?php echo '<select id="wpar_repost_taxonomies" name="wpar_repost_taxonomies[]" multiple="multiple">';
							foreach ( $taxonomies_meta as $taxonomy ) {
								$taxonomy          = $this->process_taxonomy( $taxonomy );
								$term              = get_term( $taxonomy[1] );
								if ( ! is_wp_error( $term ) || ! is_null( $term ) ) {
									$get_taxonomy_data = get_taxonomy( $term->taxonomy );
									$cat_name          = $get_taxonomy_data->label . ' : ' . $term->name;
			
									echo '<option value="' . esc_attr( join( '|', $taxonomy ) ) . '" selected="selected">' . esc_html( $cat_name ) . '</option>';
								}
							}
							echo '</select>'; ?>
						</div>
					</label>
				</div>
			</div>
			<div class="option row">
				<div class="col-3 col-12-sm">
					<label for="wpar_repost_authors_filter">
						<div class="tooltip">
							<strong><?php esc_html_e( 'Select Authors Filter', 'wp-auto-republish' ); ?>:</strong>
							<span class="tooltiptext"><?php esc_html_e( 'Select how you want to include or exclude a post author from republishing. If you choose Exclude Authors, all posts published by the selected authors will be ignored and Include will add them only.', 'wp-auto-republish' ); ?></span>
						</div>
						<?php 
						$items = array(
							'include' => __( 'Include Authors', 'wp-auto-republish' ),
							'exclude' => __( 'Exclude Authors', 'wp-auto-republish' ),
						);
						echo '<select id="wpar_repost_authors_filter" name="wpar_repost_authors_filter">';
						foreach ( $items as $item => $label ) {
							echo '<option value="' . esc_attr( $item ) . '"' . selected( $authors_filter_meta, $item, false ) . '>' . esc_html( $label ) . '</option>';
						}
						echo '</select>';
						?>
					</label>
				</div>
				<div class="col-9 col-12-sm">
					<label for="wpar_repost_authors">
						<div class="tooltip" class="tooltip">
							<strong><?php esc_html_e( 'Select Authors to Filter', 'wp-auto-republish' ); ?>:</strong>
							<span class="tooltiptext"><?php esc_html_e( 'Select authors which you want to filter to republishing using this Republish Rule.', 'wp-auto-republish' ); ?></span>
						</div>
						<div class="fields">
							<?php echo '<select id="wpar_repost_authors" name="wpar_repost_authors[]" multiple="multiple">';
							foreach ( $authors_meta as $author_id ) {
								$user = get_user_by( 'id', $author_id );
								$author = $user->display_name;
								echo '<option value="' . esc_attr( $author_id ) . '" selected="selected">' . esc_html( $author ) . '</option>';
							}
							echo '</select>'; ?>
						</div>
					</label>
				</div>
			</div>
			<div class="option row">
				<div class="col-4 col-12-sm">
					<label for="wpar_repost_post_order">
						<div class="tooltip">
							<strong><?php esc_html_e( 'Select Published Posts Order', 'wp-auto-republish' ); ?>:</strong>
							<span class="tooltiptext"><?php esc_html_e( 'Select the method of getting old posts from database.', 'wp-auto-republish' ); ?></span>
						</div>
						<?php 
						$items = array(
							'old_first' => __( 'Select Old Post First (ASC)', 'wp-auto-republish' ),
							'new_first' => __( 'Select New Post First (DESC)', 'wp-auto-republish' ),
						);
						echo '<select id="wpar_repost_post_order" name="wpar_repost_post_order">';
						foreach ( $items as $item => $label ) {
							echo '<option value="' . esc_attr( $item ) . '"' . selected( $post_order, $item, false ) . '>' . esc_html( $label ) . '</option>';
						}
						echo '</select>';
						?>
					</label>
				</div>
				<div class="col-4 col-12-sm">
					<label for="wpar_repost_post_orderby">
						<div class="tooltip">
							<strong><?php esc_html_e( 'Select Published Posts Order by', 'wp-auto-republish' ); ?>:</strong>
							<span class="tooltiptext"><?php esc_html_e( 'Select the method of getting old posts order by parameter. Default: Post Date', 'wp-auto-republish' ); ?></span>
						</div>
						<?php 
						$items = array(
							'date'          => __( 'Post Date', 'wp-auto-republish' ),
							'ID'            => __( 'Post ID', 'wp-auto-republish' ),
							'author'        => __( 'Post Author', 'wp-auto-republish' ),
							'title'         => __( 'Post Title', 'wp-auto-republish' ),
							'name'          => __( 'Post Name', 'wp-auto-republish' ),
							'rand'          => __( 'Random Selection', 'wp-auto-republish' ),
							'comment_count' => __( 'Comment Count', 'wp-auto-republish' ),
							'relevance'     => __( 'Relevance', 'wp-auto-republish' ),
							'menu_order'    => __( 'Menu Order', 'wp-auto-republish' ),
						);
						echo '<select id="wpar_repost_post_orderby" name="wpar_repost_post_orderby">';
						foreach ( $items as $item => $label ) {
							echo '<option value="' . esc_attr( $item ) . '"' . selected( $post_orderby, $item, false ) . '>' . esc_html( $label ) . '</option>';
						}
						echo '</select>'; 
						?>
					</label>
				</div>
				<div class="col-4 col-12-sm">
					<label for="wpar_repost_post_randomness">
						<div class="tooltip">
							<strong><?php esc_html_e( 'New Date Time Randomness', 'wp-auto-republish' ); ?>:</strong>
							<span class="tooltiptext"><?php esc_html_e( 'Select randomness interval from here which will be added to post republish time. If republish process runs at 11.25 AM and this option is set to Upto 1 Hour, post will be republished at anytime between 11.25 AM and 12.25 PM. It can make the republishing seem more natural to Readers and SERPs.', 'wp-auto-republish' ); ?></span>
						</div>
						<?php
						$items = array(
							'60'    => __( 'No Randomness', 'wp-auto-republish' ),
							'300'   => __( 'Upto 5 Minutes', 'wp-auto-republish' ),
							'600'   => __( 'Upto 10 Minutes', 'wp-auto-republish' ),
							'900'   => __( 'Upto 15 Minutes', 'wp-auto-republish' ),
							'1200'  => __( 'Upto 20 Minutes', 'wp-auto-republish' ),
							'1800'  => __( 'Upto 30 Minutes', 'wp-auto-republish' ),
							'2700'  => __( 'Upto 45 Minutes', 'wp-auto-republish' ),
							'3600'  => __( 'Upto 1 hour', 'wp-auto-republish' ),
							'7200'  => __( 'Upto 2 hours', 'wp-auto-republish' ),
							'14400' => __( 'Upto 4 hours', 'wp-auto-republish' ),
							'21600' => __( 'Upto 6 hours', 'wp-auto-republish' ),
							'28800' => __( 'Upto 8 hours', 'wp-auto-republish' ),
							'43200' => __( 'Upto 12 hours', 'wp-auto-republish' ),
							'86400' => __( 'Upto 24 hours', 'wp-auto-republish' ),
						);
						echo '<select id="wpar_repost_post_randomness" name="wpar_repost_post_randomness">';
						foreach ( $items as $item => $label ) {
							echo '<option value="' . esc_attr( $item ) . '"' . selected( $randomness, $item, false ) . '>' . esc_html( $label ) . '</option>';
						}
						echo '</select>';
						?>
					</label>
				</div>
			</div>

			<div class="row">
				<div class="col-3 col-12-sm">
					<label for="wpar_repost_republish_action">
						<div class="tooltip">
							<strong><?php esc_html_e( 'Post Auto Republish Action', 'wp-auto-republish' ); ?>:</strong>
							<span class="tooltiptext"><?php esc_html_e( 'Select the post republish action from here. Republish Post will actually republish your old posts and post will not be duplicated. Duplicate Post will make a copy of your existing old post and publish that. It wouldn\'t touch your old exisiting post.', 'wp-auto-republish' ); ?></span>
						</div>
						<?php 
						$items = array(
							'repost' => __( 'Republish Post', 'wp-auto-republish' ),
							'clone'  => __( 'Duplicate Post', 'wp-auto-republish' ),
							//'update'  => __( 'Update Post', 'wp-auto-republish' ),
						);
						echo '<select id="wpar_repost_republish_action" name="wpar_repost_republish_action">';
						foreach ( $items as $item => $label ) {
							echo '<option value="' . esc_attr( $item ) . '"' . selected( $republish_action, $item, false ) . '>' . esc_html( $label ) . '</option>';
						}
						echo '</select>';
						?>
					</label>
				</div>
				<div class="col-3 col-12-sm">
					<label for="wpar_repost_eligibility_age">
						<div class="tooltip">
							<strong><?php esc_html_e( 'Minimum Post Age', 'wp-auto-republish' ); ?>:</strong>
							<span class="tooltiptext"><?php esc_html_e( 'Minimum age of posts available for republish. You can use prefixes of Year, Month, Week, Day, Hour, Minutes like 1y, 2m, 3w, 4d, 5h, 6i respectively. Without suffix, plugin will assume it as minutes. Leave it blank for no limit.', 'wp-auto-republish' ); ?></span>
						</div>
						<input type="text" name="wpar_repost_eligibility_age" id="wpar_repost_eligibility_age" value="<?php echo esc_attr( $eligibility_age ); ?>" />
					</label>
				</div>
				<div class="col-3 col-12-sm">
					<label for="wpar_repost_eligibility_age_max">
						<div class="tooltip">
							<strong><?php esc_html_e( 'Maximum Post Age', 'wp-auto-republish' ); ?>:</strong>
							<span class="tooltiptext"><?php esc_html_e( 'Maximum age of posts available for republish. You can use prefixes of Year, Month, Week, Day, Hour, Minutes like 1y, 2m, 3w, 4d, 5h, 6i respectively. Without suffix, plugin will assume it as minutes. Leave it blank for no limit.', 'wp-auto-republish' ); ?></span>
						</div>
						<input type="text" name="wpar_repost_eligibility_age_max" id="wpar_repost_eligibility_age_max" value="<?php echo esc_attr( $eligibility_age_max ); ?>" />
					</label>
				</div>
				<div class="col-3 col-12-sm">
					<label for="wpar_repost_eligibility_exclude_before">
						<div class="tooltip">
							<strong><?php esc_html_e( 'Exclude Posts Published Before', 'wp-auto-republish' ); ?>:</strong>
							<span class="tooltiptext"><?php esc_html_e( 'Posts having published date after this date are eligible for republish. Republish process will ignore all posts published before this date. Leave it blank for no limit. It will override "Maximum Post Age" Settings.', 'wp-auto-republish' ); ?></span>
						</div>
						<input type="text" name="wpar_repost_eligibility_exclude_before" id="wpar_repost_eligibility_exclude_before" readonly value="<?php echo esc_attr( $eligibility_exclude_before ); ?>" />
					</label>
				</div>
			</div>
			<div class="row">
				<div class="col-4 col-12-sm">
					<label for="wpar_repost_check_thumbnail">
						<div class="tooltip">
							<strong><?php esc_html_e( 'Thumbnail based Republishing', 'wp-auto-republish' ); ?>:</strong>
							<span class="tooltiptext"><?php esc_html_e( 'Enabling this will only republish which post has a valid thumbnail. Posts with no thubnails will be ignored.', 'wp-auto-republish' ); ?></span>
						</div>
						<?php 
						$items = array(
							'enable'  => __( 'Enable', 'wp-auto-republish' ),
							'disable' => __( 'Disable', 'wp-auto-republish' ),
						);
						echo '<select id="wpar_repost_check_thumbnail" name="wpar_repost_check_thumbnail">';
						foreach ( $items as $item => $label ) {
							echo '<option value="' . esc_attr( $item ) . '"' . selected( $thumbnail_status, $item, false ) . '>' . esc_html( $label ) . '</option>';
						}
						echo '</select>';
						?>
					</label>
				</div>
				<div class="col-4 col-12-sm">
					<label for="wpar_repost_sticky_ignore">
						<div class="tooltip">
							<strong><?php esc_html_e( 'Ignore all Sticky Posts', 'wp-auto-republish' ); ?>:</strong>
							<span class="tooltiptext"><?php esc_html_e( 'Enabling this will not republish yout sticky posts. Only non-sticky posts will be queried for republish.', 'wp-auto-republish' ); ?></span>
						</div>
						<?php 
						$items = array(
							'enable'  => __( 'Enable', 'wp-auto-republish' ),
							'disable' => __( 'Disable', 'wp-auto-republish' ),
						);
						echo '<select id="wpar_repost_sticky_ignore" name="wpar_repost_sticky_ignore">';
						foreach ( $items as $item => $label ) {
							echo '<option value="' . esc_attr( $item ) . '"' . selected( $sticky_ignore, $item, false ) . '>' . esc_html( $label ) . '</option>';
						}
						echo '</select>';
						?>
					</label>
				</div>
				<div class="col-4 col-12-sm">
					<label for="wpar_repost_number_posts">
						<div class="tooltip">
							<strong><?php esc_html_e( 'No. of Posts to be Republished at a Time', 'wp-auto-republish' ); ?>:</strong>
							<span class="tooltiptext"><?php esc_html_e( 'You can set here the number of Posts to be Republished at a time. Let\'s say this is set as 5, plugin will only republish 5 available posts when a republish process runs. Use -1 for no limit.', 'wp-auto-republish' ); ?></span>
						</div>
						<input type="number" name="wpar_repost_number_posts" id="wpar_repost_number_posts" min="-1" value="<?php echo esc_attr( $number_posts ); ?>" />
					</label>
				</div>
			</div>
		</fieldset>
		<?php
	}
	
	/**
	 * Store custom field meta box data.
	 *
	 * @param int $post_id The post ID.
	 */
	public function save_metadata( $post_id ) {
		// return if autosave
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return $post_id;
		}

		// Check the user's permissions.
		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return $post_id;
		}

		// phpcs:disable WordPress.Security.NonceVerification.Missing, WordPress.Security.ValidatedSanitizedInput.MissingUnslash, WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
		if ( ! $this->verify( 'single' ) ) {
			return $post_id;
		}

		// store custom fields values
		$metas = array(
			'wpar_repost_option',
			'wpar_repost_after_number',
			'wpar_repost_after_time',
			'wpar_repost_on_date',
			'wpar_repost_repeats',
			'wpar_repost_every',
			'wpar_repost_monthly_on',
			'wpar_repost_by',
			'wpar_repost_start',
			'wpar_repost_end',
			'wpar_repost_end_after',
			'wpar_repost_end_on',
			'wpar_repost_schedule',
			'wpar_repost_done',
			'wpar_repost_at_specific_time',
			'wpar_repost_last_republish_status',
			'wpar_repost_start_time',
			'wpar_repost_end_time',
			'wpar_regenerate_cron',
			'wpar_repost_post_types',
			'wpar_repost_post_statuses',
			'wpar_repost_taxonomies_filter',
			'wpar_repost_taxonomies',
			'wpar_repost_authors_filter',
			'wpar_repost_authors',
			'wpar_repost_post_order',
			'wpar_repost_post_orderby',
			'wpar_repost_post_randomness',
			'wpar_repost_republish_action',
			'wpar_repost_eligibility_age',
			'wpar_repost_eligibility_age_max',
			'wpar_repost_eligibility_exclude_before',
			'wpar_repost_number_posts',
			'wpar_repost_check_thumbnail',
			'wpar_repost_sticky_ignore',
			'wpar_custom_date_time',
		);

		// Loop start
		foreach ( $metas as $meta_key ) {
			// check if post meta exists
			if ( ! isset( $_POST[ $meta_key ] ) ) {
				// delete post meta if not exists
				$this->delete_meta( $post_id, '_' . $meta_key );
				continue;
			}

			// get value
			$value = $_POST[ $meta_key ];
			if ( is_array( $value ) ) {
				$value = array_map( 'sanitize_text_field', $value );
			} else {
				$value = ( 'wpar_custom_date_time' === $meta_key ) ? sanitize_textarea_field( $value ) : sanitize_text_field( $value );
			}

			// add or update post meta if not exists
			$this->update_meta( $post_id, '_' . $meta_key, $value );
		}

		$regenerate = $this->get_meta( $post_id, '_wpar_regenerate_cron' );
		if ( $regenerate != 'yes' ) {
			return $post_id;
		}

		// clear count
		$this->delete_meta( $post_id, 'wpar_post_republish_count' );

		$timestamp = $this->current_timestamp();
		$option = $this->get_meta( $post_id, '_wpar_repost_option' );

        if ( in_array( $option, array( 'days', 'date', 'repeat' ) ) ) {
			$schedule = $this->get_meta( $post_id, '_wpar_repost_schedule' );
			$repost_at_time = $this->get_meta( $post_id, '_wpar_repost_at_specific_time' );

			if ( $schedule && $repost_at_time ) {
				$datetime = strtotime( date( 'Y-m-d', strtotime( $schedule ) ) . ' ' . $repost_at_time );
			}
		}

		if ( 'custom' === $option ) {
			$custom_date_time = $this->get_meta( $post_id, '_wpar_custom_date_time' );
			if ( $custom_date_time ) {
				$datetime_list = preg_split( '/\r\n|\r|\n/', $custom_date_time );
				if ( is_array( $datetime_list ) ) {
					$datetime_list = array_map( 'strtotime', array_filter( $datetime_list, array( $this, 'validate_date' ) ) );
					sort( $datetime_list );
					for ( $x = 0; $x < count( $datetime_list ); $x++ ) {
						$datetime = $datetime_list[ $x ];
						if ( $datetime > $timestamp ) {
							break;
						}
					}
					if ( isset( $datetime ) ) {
						$this->update_meta( $post_id, '_wpar_repost_schedule', date( 'm/d/Y', $datetime ) );
						$this->update_meta( $post_id, '_wpar_repost_schedule_custom', $datetime );
					}
				}
			}
		}

		if ( ! isset( $datetime ) || ! is_numeric( $datetime ) ) {
			$datetime = strtotime( '-1 day', $timestamp );
		}

		// check post status
		if ( 'publish' === get_post_status( $post_id ) ) {
			// flag to indicate that the post is saving.
			$this->update_meta( $post_id, 'wpar_post_is_saving', true );
			
			// fire cron generate action
			$this->do_action( 'republish_rule_updated', $post_id, $datetime );
		}
		//phpcs:enable

		return $post_id;
	}

	/**
	 * Store custom field meta box data.
	 *
	 * @param int $post_id The post ID.
	 */
	private function nonce( $name, $referer = true, $echo = true ) {
		\wp_nonce_field( 'wpar_nonce_' . $name, 'wpar_metabox_' . $name . '_nonce', $referer, $echo );
	}

	/**
	 * Store custom field meta box data.
	 *
	 * @param int $post_id The post ID.
	 */
	private function verify( $name ) {
		// phpcs:disable WordPress.Security.ValidatedSanitizedInput.MissingUnslash, WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
		if ( ! isset( $_REQUEST[ 'wpar_metabox_'.$name.'_nonce' ] ) || ! \wp_verify_nonce( $_REQUEST[ 'wpar_metabox_'.$name.'_nonce' ], 'wpar_nonce_'.$name ) ) {
			return false;
		}
		// phpcs:enable

		return true;
	}
}