<?php
/**
 * Premium Features.
 *
 * @since      1.3.2
 * @package    RevivePress
 * @subpackage RevivePress\Core\Premium
 * @author     Sayan Datta <iamsayan@protonmail.com>
 */

namespace RevivePress\Core\Premium;

use RevivePress\Helpers\Hooker;
use RevivePress\Helpers\Scheduler;
use RevivePress\Helpers\Premium\SocialHelpers;

defined( 'ABSPATH' ) || exit;

/**
 * Register Scheduler Tasks class.
 */
class ScheduleTasks
{
	use Hooker;
    use Scheduler;
    use SocialHelpers;

	/**
	 * Register functions.
	 */
	public function register() {
		$this->action( 'wpar/old_post_republished', 'create_tasks' );
	}

	/**
	 * Create tasks with 15 seconds interval.
	 */
	public function create_tasks( $post_id ) {
		$counter = 0;

		// Create social task if the post is actually published.
		if ( 'publish' === get_post_status( $post_id ) ) {
			$counter = $this->create_social_tasks( $post_id );
		}

		// Create email.
		$email_disabled = $this->get_meta( $post_id, '_wpar_disable_email' );
		if ( $this->is_enabled( 'enable_email_notify' ) && ! $email_disabled ) {
			$this->schedule_single_action( time() + ( 20 * ( ( $counter + 1 ) / 2 ) ), 'wpar/process_email_notify', array( $post_id ) );
		}
	}

	/**
	 * Create tasks with 15 seconds interval.
	 */
	public function create_social_tasks( $post_id ) {
		$counter = 0;
		foreach ( $this->get_social_providers() as $provider ) {
			$is_disabled = $this->get_meta( $post_id, '_wpar_disable_' . $provider . '_share' );
			if ( $this->is_enabled( $provider . '_enable' ) && ! $is_disabled ) {
				++$counter;
				$this->schedule_single_action( time() + ( 20 * ( $counter / 2 ) ), 'wpar/process_' . $provider . '_share', array( $post_id, false ) );
			}
		}

		return $counter;
	}
}