<?php
/**
 * Link Shortners.
 *
 * @since      1.4.6
 * @package    RevivePress
 * @subpackage RevivePress\Helpers\Premium
 * @author     Sayan Datta <iamsayan@protonmail.com>
 */

namespace RevivePress\Core\Premium\Social;

use RevivePress\Helpers\Hooker;
use RevivePress\Helpers\SettingsData;

defined( 'ABSPATH' ) || exit;

/**
 * Meta & Option class.
 */
class LinkShortner
{
	use Hooker;
    use SettingsData;

	/**
	 * Register functions.
	 */
	public function register() {
		$this->filter( 'wpar/post_permalink_tinyurl', 'tinyurl_shorten' );
		$this->filter( 'wpar/post_permalink_is_gd', 'is_gd_shorten' );
		$this->filter( 'wpar/post_permalink_bitly', 'bitly_shorten' );
		$this->filter( 'wpar/post_permalink_shortest', 'shortest_shorten' );
	}

	/**
	 * TinyURL Shortner
	 *
	 * @return string
	 */
	public function tinyurl_shorten( $url ) {
		$tiny_url = wp_remote_fopen( esc_url_raw( 'http://tinyurl.com/api-create.php?url=' . urlencode( $url ) ) ); // phpcs:ignore WordPress.PHP.DiscouragedPHPFunctions.urlencode_urlencode
		if ( $tiny_url ) {
			return $tiny_url;
		}

		return $url;
	}
	
	/**
	 * is.gd shortner.
	 *
	 * @return string
	 */
	public function is_gd_shorten( $url ) {
		$isgd_url = wp_remote_fopen( esc_url_raw( 'https://is.gd/create.php?format=simple&url=' . urlencode( $url ) ) ); // phpcs:ignore WordPress.PHP.DiscouragedPHPFunctions.urlencode_urlencode
		if ( $isgd_url ) {
			return $isgd_url;
		}
		
		return $url;
	}

	/**
	 * bit.ly shortner.
	 *
	 * @return string
	 */
	public function bitly_shorten( $url ) {
		$token = $this->get_data( 'bitly_token' );
		if ( ! empty( $token ) ) {
			$request_uri = 'https://api-ssl.bitly.com/v3/shorten?' .
				'access_token=' . $token .
				'&longUrl=' . urlencode( $url ); // phpcs:ignore WordPress.PHP.DiscouragedPHPFunctions.urlencode_urlencode
				
			$request_uri = esc_url_raw( $request_uri );
			$encoded_data = wp_remote_fopen( $request_uri ); 
			
			if ( $encoded_data ) {
				$decoded_result = json_decode( $encoded_data );
				if ( $decoded_result && $decoded_result->status_code == 200 && isset( $decoded_result->data ) && isset( $decoded_result->data->url ) ) {
					return $decoded_result->data->url;  
				}
			}
		}
		
		return $url;
	}

	/**
	 * Shorte.st shortner.
	 *
	 * @return string
	 */
	public function shortest_shorten( $url ) {
		$token = $this->get_data( 'shortest_token' );
		if ( ! empty( $token ) ) {
			$response = wp_remote_request( 'https://api.shorte.st/v1/data/url',
				array(
					'timeout'   => 120,
					'method'    => 'PUT',
					'sslverify' => false,
					'headers'   => array(
						'public-api-token' => $token,
					),
					'body'      => array(
						'urlToShorten' => $url,
					),
				)
			);

			$shortest = json_decode( $response['body'] );
			if ( $shortest ) {
				return $shortest->{'shortenedUrl'};
			}
		}

		return $url;
	}
}