<?php
/**
 * The file for Social Actions.
 *
 * @since      1.2.2
 * @package    RevivePress
 * @subpackage RevivePress\Core\Premium
 * @author     Sayan Datta <iamsayan@protonmail.com>
 */

// @codingStandardsIgnoreFile

namespace RevivePress\Core\Premium\Social;

use RevivePress\Helpers\Hooker;
use RevivePress\Helpers\Premium\SocialHelpers;

defined( 'ABSPATH' ) || exit;

/**
 * Social Actions class.
 */
class SocialActions
{
	use Hooker, SocialHelpers;

	/**
	 * Register functions.
	 */
	public function register() {
		$this->filter( 'allowed_redirect_hosts', 'allowed_redirect_hosts' );
		$this->action( 'wpar/social_auth_fields', 'auth_fields' );
		$this->filter( 'wpar/social_template_tags', 'generate_template_tags' );
		$this->action( 'admin_notices', 'admin_notice' );
	}

	/**
	 * Filter WordPress Redirect hosts to add RevivePress domain.
	 */
	public function allowed_redirect_hosts( $hosts ) {
		$hosts[] = 'api.wprevivepress.com';
		
		return $hosts;
	}

	/**
	 * Activate or Deactivate Single Social account on request.
	 */
	public function auth_fields( $provider ) { ?>
		<div id="wpar-<?php echo esc_attr( $provider ); ?>-form" style="display: none !important;">
			<div class="social-form">
				<label>
					<?php esc_html_e( 'Callback URL:', 'wp-auto-republish' ); ?>
					<div>
						<input type="text" id="<?php echo esc_attr( $provider ); ?>-callback-url" class="wpar-form-control" autocomplete="new-password" style="width: 85%" value="https://api.wprevivepress.com/auth/<?php echo esc_attr( $provider ); ?>" readonly />
					</div>
				</label>
				<div style="font-size: 12px;">
					<?php printf( 
						/* translators: Social Provider name. */
						esc_html__( 'Copy and Paste it in your %s App Callback URL field.', 'wp-auto-republish' ), esc_html( ucwords( $provider ) ) 
					); ?></div><div class="wpar-clear">
				</div>
				<label>
					<?php esc_html_e( 'Enter API Key:', 'wp-auto-republish' ); ?>
					<div>
						<input type="text" id="<?php echo esc_attr( $provider ); ?>-app-id" class="wpar-form-control" autocomplete="new-password" style="width: 85%" value="<?php echo esc_attr( apply_filters( 'wpar/' . $provider . '_auth_api_key', $this->get_credentials( $provider, 'app_id' ) ) ); ?>" />
					</div>
				</label>
				<div class="wpar-clear"></div>
				<label>
					<?php esc_html_e( 'Enter API Secret:', 'wp-auto-republish' ); ?>
					<div>
						<input type="password" id="<?php echo esc_attr( $provider ); ?>-app-secret" class="wpar-form-control" autocomplete="new-password" style="width: 85%" value="<?php echo esc_attr( apply_filters( 'wpar/' . $provider . '_auth_secret_key', $this->get_credentials( $provider, 'app_secret' ) ) ); ?>" />
					</div>
				</label>
				<div class="wpar-clear"></div>
				<span style="font-size: 12px;">
					<?php printf( 
						/* translators: 1: <a> tag start, 2: </a> tag end. */
						esc_html__( 'You can find all of your credentials %1$shere%2$s.', 'wp-auto-republish' ), '<a href="https://api.wprevivepress.com/go/social?provider=' . esc_html( $provider ) . '" target="_blank">', '</a>' 
					); ?>
				</span>
			</div>
		</div>
		<?php
	}

	/**
	 * Generate template tags output.
	 */
	public function generate_template_tags( $provider ) {
		ob_start() ?>
		<div class="dynamic-tags dynamic-tags-<?php echo esc_attr( $provider ); ?>">
			<div class="dynamic-tags-label">
				<?php printf( 
					/* translators: Social Provider name. */
					esc_html__( 'Here you can enter default content which will be used for the %s posting. You can use some pre-built template tags within the content template. Available Dynamic Tags', 'wp-auto-republish' ), ucwords( $provider ) 
				); ?>:
			</div>
			<div class="dynamic-tags-content"><?php echo $this->get_available_tags_list(); ?></div>
		</div>
		<?php
		return ob_get_clean();
	}

	/**
	 * Get avaialable template tags list.
	 * 
	 * @since 1.3.4
	 * @return string
	 */
	public function get_available_tags_list() {
		$tags = $this->get_available_tags();
		array_push( $tags, '%cf_fieldname%' );

		$content = [];
		foreach ( $tags as $tag ) {
			$content[] = '<code class="click-to-copy" title="' . esc_attr__( 'Click to Copy', 'wp-auto-republish' ) . '">' . esc_html( $tag ) . '</code>';
		}

		return join( ' ', $content );
	}

	/**
     * Process reset plugin settings
     */
	public function admin_notice() {
    	if ( get_transient( 'rvp_social_account_added' ) !== false ) { ?>
			<div class="notice notice-success is-dismissible">
				<p>
					<strong>RevivePress</strong>: <em><?php printf( 
						/* translators: Social Provider name. */
						esc_html__( 'Success! Your %s account(s) added successfully.', 'wp-auto-republish' ), ucwords( str_replace( [ '_', '-' ], ' ', get_transient( 'rvp_social_account_added' ) ) ) 
					); ?></em>
				</p>
			</div><?php 
		    delete_transient( 'rvp_social_account_added' );
	    }
	}
}