<?php
/**
 * Helper functions.
 *
 * @since      1.4.9
 * @package    RevivePress
 * @subpackage RevivePress\Helpers
 * @author     Sayan Datta <iamsayan@protonmail.com>
 */

namespace RevivePress\Core\Premium;

use RevivePress\Helpers\Hooker;
use RevivePress\Helpers\HelperFunctions;

defined( 'ABSPATH' ) || exit;

/**
 * Logger class.
 */
class Taxonomy
{
	use Hooker;
    use HelperFunctions;

	/**
	 * Republish Tag taxonomy slug.
	 *
	 * @var string
	 */
	private $taxonomy = 'republish_tag';

	/**
	 * Republish Tags menu item parent slug.
	 *
	 * @var string
	 */
	private $menu_slug = 'revivepress';
	
	/**
	 * Register functions.
	 */
	public function register() {
		$this->action( 'init', 'register_taxonomy' );
		$this->action( 'admin_menu', 'admin_menu', 8 );
		$this->filter( 'parent_file', 'highlight_menu' );
	}

	/**
	 * Register Custom Taxonomy
	 */
	public function register_taxonomy() {
		register_extended_taxonomy( $this->taxonomy, $this->get_post_types( true ),
		array(
			'hierarchical'       => false,
	    	'public'             => true,
	    	'show_ui'            => true,
	    	'show_in_menu'       => false,
	    	'show_in_admin_bar'  => false,
	    	'show_in_nav_menus'  => false,
	    	'show_admin_column'  => true,
	    	'publicly_queryable' => false,
			'show_tagcloud'      => false,
			'rewrite'            => false,
			'query_var'          => true,
			'meta_box'           => 'simple',
			'description'        => __( 'Custom Taxonomy for Filter posts based on this taxonomy.', 'wp-auto-republish' ),
		),
		array(
			'singular' => __( 'Republish Tag', 'wp-auto-republish' ),
			'plural'   => __( 'Republish Tags', 'wp-auto-republish' ),
			'slug'     => $this->taxonomy,
		) );
	}

	/**
	 * Register Sub Menu page.
	 */
	public function admin_menu() {
		$manage_options_cap = $this->do_filter( 'manage_options_capability', 'manage_options' );

		add_submenu_page(
			$this->menu_slug, 
			__( 'Republish Tags', 'wp-auto-republish' ), 
			__( 'Republish Tags', 'wp-auto-republish' ), 
			$manage_options_cap, 
			'edit-tags.php?taxonomy=' . $this->taxonomy,
		);
	}

	/**
	 * Filters the parent file to show menu item as active.
	 */
	public function highlight_menu( $parent_file ) {
        global $current_screen;

        $taxonomy = $current_screen->taxonomy;
        if ( $this->taxonomy === $taxonomy ) {
            $parent_file = $this->menu_slug;
        }

        return $parent_file;
    }
}