<?php
/**
 * Fetch next republish schedule.
 *
 * @since      1.1.0
 * @package    RevivePress
 * @subpackage RevivePress\Helpers\Premium
 * @author     Sayan Datta <iamsayan@protonmail.com>
 */

namespace RevivePress\Helpers\Premium;

use RevivePress\Helpers\HelperFunctions;

defined( 'ABSPATH' ) || exit;

/**
 * Post Meta class.
 */
trait GetMetaData
{
	use HelperFunctions;

	/**
	 * Get post metadata.
	 * 
	 * @param int    $post_id  Post ID
	 * @param string $type     Output type
	 * @param bool   $column   Is admin column output
	 * 
	 * @return string
	 */
	protected function get_schedule( $post_id, $type = 'raw', $column = false ) {
		$option = $this->get_meta( $post_id, '_wpar_repost_option' );
		$number = $this->get_meta( $post_id, '_wpar_repost_after_number' );
		$time = $this->get_meta( $post_id, '_wpar_repost_after_time' );
		$repeats = $this->get_meta( $post_id, '_wpar_repost_repeats' );
		$every = $this->get_meta( $post_id, '_wpar_repost_every' );
		$weekly = maybe_unserialize( $this->get_meta( $post_id, '_wpar_repost_on' ) );
		if ( empty( $weekly ) ) $weekly = array();
		
		$monthly = $this->get_meta( $post_id, '_wpar_repost_by' );
		$end = $this->get_meta( $post_id, '_wpar_repost_end' );
		$occurence = $this->get_meta( $post_id, '_wpar_repost_end_after' );
		$return = '';
		
		$timestamp = $this->current_timestamp();
		$repost_monthly_on = $this->get_meta( $post_id, '_wpar_repost_monthly_on', array(), true );
		$on = strtotime( $this->get_meta( $post_id, '_wpar_repost_on_date' ) );
		$end_on = $this->get_meta( $post_id, '_wpar_repost_end_on' );
		$schedule = $this->get_meta( $post_id, '_wpar_repost_schedule' );
		$repost_at_time = $this->get_meta( $post_id, '_wpar_repost_schedule_datetime' );
		$full_schedule = $this->get_meta( $post_id, '_wpar_repost_schedule_custom' );

		$schedule = ( $schedule ) ? strtotime( $schedule ) : false;
		$datetime = ( $repost_at_time ) ? strtotime( $repost_at_time ) : false;

		$today = date( 'm/d/Y', $timestamp );
		$format = get_option( 'date_format' );
		$prefix = true;

		switch ( $option ) {
			case 'days':
			case 'date':
				if ( ! $column ) {
			    	if ( strtotime( $today ) == $schedule ) {
			    		$return .= sprintf( 
							/* translators: 1: Republish hint, 2: Formatted datetime. */
							'%1$s, <strong>%2$s</strong>', __( 'Set today', 'wp-auto-republish' ), date_i18n( $format, $schedule ) 
						);
			    	} elseif ( strtotime( $today ) >= $schedule ) {
			    		$return .= sprintf( 
							/* translators: 1: Republish hint, 2: Formatted datetime. */
							__( '%1$s <strong>%2$s</strong>', 'wp-auto-republish' ), __( 'Was set on', 'wp-auto-republish' ), date_i18n( $format, $schedule ) 
						);
			    	} else {
			    		$return .= sprintf( 
							/* translators: 1: Republish hint, 2: Formatted datetime. */
							'%1$s <strong>%2$s</strong>', __( 'Set on', 'wp-auto-republish' ), date_i18n( $format, $schedule ) 
						);
			    	}
			    }
				break;

			case 'custom':
				if ( $column ) {
					$return .= __( 'Custom Republish Schedule', 'wp-auto-republish' );
					$prefix = false;
				} elseif ( $full_schedule && $full_schedule >= $timestamp ) {
						$format .= ' @ ' . get_option( 'time_format' );
						if ( strtotime( $today ) == $schedule ) {
							$return .= sprintf( 
								/* translators: 1: Republish hint, 2: Formatted datetime. */
								'%1$s, <strong>%2$s</strong>', __( 'Set today', 'wp-auto-republish' ), date_i18n( $format, $full_schedule ) 
							);
						} elseif ( strtotime( $today ) >= $schedule ) {
							$return .= sprintf( 
								/* translators: 1: Republish hint, 2: Formatted datetime. */
								__( '%1$s <strong>%2$s</strong>', 'wp-auto-republish' ), __( 'Was set on', 'wp-auto-republish' ), date_i18n( $format, $full_schedule ) 
							);
						} else {
							$return .= sprintf( 
								/* translators: 1: Republish hint, 2: Formatted datetime. */
								'%1$s <strong>%2$s</strong>', __( 'Set on', 'wp-auto-republish' ), date_i18n( $format, $full_schedule ) 
							);
						}
					} else {
						$return .= __( 'Not set', 'wp-auto-republish' );
				}
				break;
			
			case 'repeat':
				switch ( $repeats ) {
					case 'yearly':
						$return .= sprintf(
							/* translators: 1: Republish hint, 2: Formatted datetime. */
							'%1$s <strong>%2$s</strong>',
							__( 'Set', 'wp-auto-republish' ),
							( $every > 1 ) ? sprintf( 
								/* translators: Number of repeated years. */
								__( 'every %s years', 'wp-auto-republish' ), $every 
							) : 
							__( 'Yearly', 'wp-auto-republish' )
						);
						break;
					
					case 'monthly':
						$return .= sprintf(
							/* translators: 1: Republish hint, 2: Formatted datetime, 3: Republish hint, 4: republish schedule info. */
							'%1$s <strong>%2$s</strong> %3$s <strong>%4$s</strong>',
							__( 'Set', 'wp-auto-republish' ),
							( $every > 1 ) ? sprintf( 
								/* translators: Number of repeated months. */
								__( 'every %s months', 'wp-auto-republish' ), $every 
							) : __( 'Monthly', 'wp-auto-republish' ),
							__( 'on', 'wp-auto-republish' ),
							( $monthly == 'month' ) ? sprintf( 
								/* translators: Number of week day. */
								__( 'Day %s', 'wp-auto-republish' ), date_i18n( 'd', $schedule ) 
							) : sprintf( 
								/* translators: Week day details. */
								__( 'the %s', 'wp-auto-republish' ), $this->get_nth_week( $schedule ) . ' ' . $this->get_day_by_name( lcfirst( date( 'l', $schedule ) ) ) 
							)
						);
						break;
					
					case 'weekly':
						$return .= sprintf(
							/* translators: 1: Republish hint, 2: Formatted datetime, 3: Republish hint, 4: republish schedule info. */
							'%1$s <strong>%2$s</strong> %3$s <strong>%4$s</strong>',
							__( 'Set', 'wp-auto-republish' ),
							( $every > 1 ) ? sprintf( 
								/* translators: number of weeks. */
								__( 'every %s weeks', 'wp-auto-republish' ), $every 
							) : __( 'Weekly', 'wp-auto-republish' ),
							__( 'on', 'wp-auto-republish' ),
							$this->get_day_by_name( lcfirst( date( 'l', $schedule ) ) )
						);
						break;
					
					case 'daily':
						$return .= sprintf(
							/* translators: 1: Republish hint, 2: Formatted datetime. */
							'%1$s <strong>%2$s</strong>',
							__( 'Set', 'wp-auto-republish' ),
							( $every > 1 ) ? sprintf( 
								/* translators: number of days. */
								__( 'every %s days', 'wp-auto-republish' ), $every
							) : __( 'Daily', 'wp-auto-republish' )
						);
						break;

					case 'hourly':
						$return .= sprintf(
							/* translators: 1: Republish hint, 2: Formatted datetime. */
							'%1$s <strong>%2$s</strong>',
							__( 'Set', 'wp-auto-republish' ),
							( $every > 1 ) ? sprintf( 
								/* translators: number of hours. */
								__( 'every %s hours', 'wp-auto-republish' ), $every 
							) : __( 'Hourly', 'wp-auto-republish' )
						);
						break;

					default:
					case 'minutes':
						$return .= sprintf(
							/* translators: 1: Republish hint, 2: Formatted datetime. */
							'%1$s <strong>%2$s</strong>',
							__( 'Set', 'wp-auto-republish' ),
							( $every > 1 ) ? sprintf( 
								/* translators: number of minutes. */
								__( 'every %s minutes', 'wp-auto-republish' ), $every 
							) : __( 'In Minutes', 'wp-auto-republish' )
						);
						break;
				}

				if ( $end == 'after' ) {
					$return .= sprintf( ' @ <strong>%1$s</strong> %2$s', $occurence, __( 'times', 'wp-auto-republish' ) );
				} elseif ( $end == 'on' ) {
					$return .= sprintf( ', %1$s <strong>%2$s</strong>', __( 'until', 'wp-auto-republish' ), date_i18n( $format, strtotime( $end_on ) ) );
				}

				if ( ! $column ) {
				    $return .= sprintf( '. %1$s <strong>%2$s</strong>', __( 'Next republish schedule is on', 'wp-auto-republish' ), date_i18n( $format, $schedule ) );
				}
			    break;
		}

		if ( $column && ! empty( $return ) ) {
			$return = $prefix ? sprintf( 
				/* translators: Republish schedule. */
				__( 'Republish %s', 'wp-auto-republish' ), $return 
			) : $return;
		}
		
		if ( $type == 'raw' ) {
			return $schedule;
		}
	
		if ( $type == 'datetime' ) {
			return $datetime;
		}

		return $return;
	}
	
	/**
	 * Generate week number.
	 * 
	 * @param int    $timestamp Post date
	 * 
	 * @return string
	 */
	private function get_nth_week( $timestamp ) {
		$timestamp = is_numeric( $timestamp ) ? $timestamp : strtotime( $timestamp );
		$weekday   = date( 'l', $timestamp );
		$month     = date( 'M', $timestamp );   
		$ord       = 0;
	
		while ( date( 'M', ( $timestamp = strtotime( '-1 week', $timestamp ) ) ) == $month ) { // phpcs:ignore WordPress.CodeAnalysis.AssignmentInCondition.FoundInWhileCondition
			++$ord;
		}
	
		$weekdays = array( 'first', 'second', 'third', 'fourth', 'fifth' );

		return $weekdays[ $ord ];
	}

	/**
	 * Generate week name.
	 * 
	 * @param string   $name  Weekday name
	 * @return string  $name  translated Weekday name
	 */
	private function get_day_by_name( $name ) {
		$array = array(
			'sunday'    => __( 'Sunday', 'wp-auto-republish' ),
			'monday'    => __( 'Monday', 'wp-auto-republish' ),
			'tuesday'   => __( 'Tuesday', 'wp-auto-republish' ),
			'wednesday' => __( 'Wednesday', 'wp-auto-republish' ),
			'thursday'  => __( 'Thursday', 'wp-auto-republish' ),
			'friday'    => __( 'Friday', 'wp-auto-republish' ),
			'saturday'  => __( 'Saturday', 'wp-auto-republish' ),
		);
		
		return $array[ $name ];
	}
}