<?php
/**
 * Register all classes
 *
 * @since      1.1.0
 * @package    RevivePress
 * @subpackage RevivePress\Core
 * @author     Sayan Datta <iamsayan@protonmail.com>
 */

namespace RevivePress;

/**
 * Main Class.
 */
final class Loader
{
	/**
	 * Store all the classes inside an array
	 * 
	 * @return array Full list of classes
	 */
	public static function get_services() {
		$services = array(
			Pages\Dashboard::class,
			Base\Enqueue::class,
			Base\Admin::class,
			Base\Actions::class,
			Base\Localization::class,
			Base\RatingNotice::class,
			Core\FetchPosts::class,
			Core\PostRepublish::class,
			Core\RewritePermalinks::class,
			Core\SiteCache::class,
			Core\RepublishInfo::class,
			Tools\Database::class,
			Tools\Updates::class,
		);

		if ( revivepress_fs()->can_use_premium_code__premium_only() ) {
	        $premium_services = array(
	        	Core\Premium\AdminColumnView::class,
	        	Core\Premium\DashboardWidget::class,
				Core\Premium\Filters::class,
				Core\Premium\EventLogger::class,
	        	Core\Premium\PostMetaBox::class,
				Core\Premium\Notification::class,
				Core\Premium\InstantRepublish::class,
				Core\Premium\PostStatusFilters::class,
				Core\Premium\ScheduleTasks::class,
				Core\Premium\SingleCache::class,
				Core\Premium\SingleRepublish::class,
				Core\Premium\TriggerEvent::class,
				Core\Premium\ScheduledEvent::class,
				Core\Premium\Capabilities::class,
				Core\Premium\Taxonomy::class,
				Core\Premium\Rules\PostType::class,
				Core\Premium\Rules\RuleMetaBox::class,
				Core\Premium\Rules\RuleActions::class,
				Core\Premium\Rules\GetPosts::class,
				Core\Premium\Social\RestApi::class,
				Core\Premium\Social\LinkShortner::class,
				Core\Premium\Social\SocialActions::class,
				Core\Premium\Social\Providers\FacebookShare::class,
				Core\Premium\Social\Providers\LinkedinShare::class,
				Core\Premium\Social\Providers\TwitterShare::class,
				Core\Premium\Social\Providers\PinterestShare::class,
				Core\Premium\Social\Providers\TumblrShare::class,
			);

			$services = array_merge( $services, $premium_services );
	    }
		
		return $services;
	}

	/**
	 * Loop through the classes, initialize them, 
	 * and call the register() method if it exists
	 */
	public static function register_services() {
		foreach ( self::get_services() as $class ) {
			$service = self::instantiate( $class );
			if ( method_exists( $service, 'register' ) ) {
				$service->register();
			}
		}
	}

	/**
	 * Initialize the class
	 * 
	 * @param  class $class    class from the services array
	 * @return class instance  new instance of the class
	 */
	private static function instantiate( $class ) {
		$service = new $class();

		return $service;
	}
}