<?php
/**
 * The Updates routine for version 1.4.3.1
 *
 * @since      1.4.3.1
 * @package    RevivePress
 * @subpackage RevivePress\Tools\updates\premium
 * @author     Sayan Datta <iamsayan@protonmail.com>
 */

defined( 'ABSPATH' ) || exit;

/**
 * v1.4.3.1 migration
 */
function revivepress_1_4_3_1_migration() {
	// gets the administrator role
	$role_object = get_role( 'administrator' );
	if ( is_null( $role_object ) || ! $role_object instanceof \WP_Role ) {
		return;
	}

	$post_types = array(
		'republish_rule',
		'republish_log',
	);

	foreach ( $post_types as $post_type ) {
		$caps = get_capabilities_1_4_3_1_migration( $post_type );
		foreach ( $caps as $cap ) {
			$role_object->remove_cap( $cap );
			$role_object->add_cap( $cap );
		}
	}

	$settings = ( array ) get_option( 'wpar_plugin_settings' );
	$new_settings = array_merge( $settings, array(
		'enable_republish_log' => 1,
	) );
	update_option( 'wpar_plugin_settings', $new_settings );
}
revivepress_1_4_3_1_migration();

/**
 * Get Capability lists.
 */
function get_capabilities_1_4_3_1_migration( $singular, $plural = null ) {
	if ( ! $plural ) {
		$plural = $singular . 's';
	}
	return array(
		'edit_post'              => "edit_$singular",
		'read_post'              => "read_$singular",
		'delete_post'            => "delete_$singular",
		'edit_posts'             => "edit_$plural",
		'edit_others_posts'      => "edit_others_$plural",
		'publish_posts'          => "publish_$plural",
		'read_private_posts'     => "read_private_$plural",
		'delete_posts'           => "delete_$plural",
		'delete_private_posts'   => "delete_private_$plural",
		'delete_published_posts' => "delete_published_$plural",
		'delete_others_posts'    => "delete_others_$plural",
		'edit_private_posts'     => "edit_private_$plural",
		'edit_published_posts'   => "edit_published_$plural",
		'create_posts'           => "edit_$plural",
	);
}